@@ -7,7 +7,7 @@ from foresight.utils.auth import create_google_calendar_service
 
 class GoogleCalendar:
     def __init__(self, service: Optional[Any] = None) -> None:
-        self.service = service or create_google_calendar_service()
+        self.service = service
 
     def events(self, start_date: str, end_date: str) -> List[Event]:
         events_result = (
